
reader
======

.. include:: ../README.rst
  :start-after: begin-intro
  :end-before: end-intro


Features
--------

.. include:: ../README.rst
  :start-after: begin-features
  :end-before: end-features


Quickstart
----------

What does it look like? Here is an example of *reader* in use:

.. include:: ../README.rst
  :start-after: begin-usage
  :end-before: end-usage


User guide
----------

This part of the documentation guides you through all of the library’s usage patterns.

.. toctree::
    :maxdepth: 2

    why
    install
    tutorial
    guide


API reference
-------------

If you are looking for information on a specific function, class, or method,
this part of the documentation is for you.

.. toctree::
    :maxdepth: 2

    api


Unstable features
-----------------

The following are optional features that are still being worked on.
They may become their own packages, get merged into the main library,
or be removed in the future.

.. toctree::
    :maxdepth: 2

    cli
    app
    config
    plugins


Project information
-------------------

*reader* is released under the :gh:`BSD <LICENSE>` license,
its documentation lives at `Read the Docs`_,
the code on `GitHub`_,
and the latest release on `PyPI`_.
It is rigorously tested on Python 3.7+ and PyPy.


.. _Read the Docs: https://reader.readthedocs.io/
.. _GitHub: https://github.com/lemon24/reader
.. _PyPI: https://pypi.org/project/reader/


.. toctree::
    :maxdepth: 2

    compat
    dev
    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
